## CChecksum

CChecksum is a ~2x faster drop-in replacement for eth_utils.to_checksum_address, with the most cpu-intensive part implemented in c.

Just `pip install cchecksum`, drop it in, and run your script with a substantial speed improvement.

![image](https://github.com/user-attachments/assets/a2da6950-2759-42fa-8a56-7d7e095cd2ce)
